@@ -20,6 +20,12 @@ setMethod(
     pt <- object@partable
     pt$pval <- pt$zval <- pt$SE <- NA
     vcov_fit <- object@vcov
+    creg_options <- input@creg_options
+
+    fixed_z <- FALSE
+    if (!is.null(creg_options$fixed_z)) {
+      fixed_z <- creg_options$fixed_z |> as.logical()
+    }
 
     if (input@se & !is.null(vcov_fit)) {
       SE <- sqrt(diag(vcov_fit))
@@ -39,7 +45,11 @@ setMethod(
 
       # Print regression coefficients
       cat("Regression:\n")
-      res_rows <- pt_g$dest == "beta" | pt_g$dest == "gamma"
+      res_rows <- pt_g$dest == "beta" |
+        pt_g$dest == "gamma" |
+        pt_g$dest == "Beta" |
+        pt_g$dest == "Gamma" |
+        pt_g$dest == "Omega"
       res_cols <- c("rhs", "par", "SE", "zval", "pval")
       res <- pt_g[res_rows, res_cols]
       rownames(res) <- res$rhs
@@ -58,7 +68,7 @@ setMethod(
         print(res, digits = 3, print.gap = 3)
       }
 
-      if (no_z | no_lv) {
+      if ((no_z & !fixed_z) | no_lv) {
         # Print means and variances of the covariates
         cat("\nMeans:\n")
         res_rows <- pt_g$dest == "mu_z" | pt_g$dest == "mu_eta"
@@ -78,23 +88,28 @@ setMethod(
         res <- res[, -1]
         names(res) <- c("Estimate", "SE", "Est./SE", "p-value")
         print(res, digits = 3, print.gap = 3)
+
+
+        cond_cov_z <- no_z >= 2 & !fixed_z
+        cond_cov_lv <- no_lv >= 2
+        cond_cov_lv_z <- no_z >= 1 & no_lv >= 1 & !fixed_z
+
+
+        if (cond_cov_z | cond_cov_lv | cond_cov_lv_z) {
+          # Print covariances of covariates
+          cat("\nCovariances:\n")
+          res_rows <- (pt_g$type == "cov" &
+            (pt_g$dest == "Sigma_z" | pt_g$dest == "Sigma_eta")) |
+            pt_g$dest == "Sigma_z_lv"
+          res_cols <- c("lhs", "op", "rhs", "par", "SE", "zval", "pval")
+          res <- pt_g[res_rows, res_cols]
+          rownames(res) <- paste(res$lhs, res$op, res$rhs)
+          res <- res[, -c(1:3)]
+          names(res) <- c("Estimate", "SE", "Est./SE", "p-value")
+          print(res, digits = 3, print.gap = 3)
+        }
       }
 
-      if (no_z + no_lv >= 2) {
-        # Print covariances of covariates
-        cat("\nCovariances:\n")
-        res_rows <- (
-          pt_g$type == "cov" &
-            (pt_g$dest == "Sigma_z" | pt_g$dest == "Sigma_eta")
-        ) |
-          pt_g$dest == "Sigma_z_lv"
-        res_cols <- c("lhs", "op", "rhs", "par", "SE", "zval", "pval")
-        res <- pt_g[res_rows, res_cols]
-        rownames(res) <- paste(res$lhs, res$op, res$rhs)
-        res <- res[, -c(1:3)]
-        names(res) <- c("Estimate", "SE", "Est./SE", "p-value")
-        print(res, digits = 3, print.gap = 3)
-      }
 
       if (no_lv) {
         # Print measurement model
