@@ -10,8 +10,11 @@ arma::vec dmvnrm_arma_fast(arma::mat const &x, arma::mat const &mean,
                            arma::mat const &sigma, bool const logd,
                            int const cores);
 arma::colvec dpois_cpp(arma::colvec y, arma::colvec mu_beta,
-                       arma::colvec mu_Beta, arma::colvec mu_y_lv,
+                       arma::colvec mu_gamma, arma::colvec mu_Beta,
+                       arma::colvec mu_Gamma, arma::mat mu_Omega,
                        int const cores);
-arma::colvec dnegbin_cpp(arma::colvec y, arma::colvec mu_y_z,
-                         arma::colvec mu_y_lv, double alpha, int const cores);
+arma::colvec dnegbin_cpp(arma::colvec y, arma::colvec mu_beta,
+                         arma::colvec mu_gamma, arma::colvec mu_Beta,
+                         arma::colvec mu_Gamma, arma::mat mu_Omega,
+                         double alpha, int const cores);
 #endif
